@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2024 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2025 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -394,6 +394,8 @@
   N_("Bar")
 #define HTML_REPORT_PANEL_WMAP         \
   N_("World Map")
+#define HTML_REPORT_PANEL_GMAP         \
+  N_("Azimuthal/Globe")
 #define HTML_REPORT_PANEL_PLOT_METRIC  \
   N_("Plot Metric")
 #define HTML_REPORT_PANEL_TABLE_COLS   \
@@ -588,4 +590,14 @@
 #define STATUS_CODE_783               \
   N_("783 - Unexpected Token: The request includes a JSON syntax error")
 
+/* Menu buttons */
+#define HTML_REPORT_NAV_BUTTON_MENU                 \
+N_("Menu")
+#define HTML_REPORT_NAV_BUTTON_SETTINGS             \
+N_("Settings")
+#define HTML_REPORT_WEBSOCKET_STATUS_CONNECTED      \
+N_("WebSocket Status: Connected")
+#define HTML_REPORT_WEBSOCKET_STATUS_DISCONNECTED   \
+N_("WebSocket Status: Disconnected")
+
 #endif // for #ifndef LABELS_H
